cli

package
v0.0.0-...-2831af8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 4, 2017 License: GPL-3.0 Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterCommands

func RegisterCommands(app *cobra.Command, c *client.Client)

RegisterCommands registers the resource action CLI commands.

Types

type LoginUserCommand

type LoginUserCommand struct {
	// Username
	Username    string
	PrettyPrint bool
}

LoginUserCommand is the command line data structure for the login action of user

func (*LoginUserCommand) RegisterFlags

func (cmd *LoginUserCommand) RegisterFlags(cc *cobra.Command, c *client.Client)

RegisterFlags registers the command flags with the command line.

func (*LoginUserCommand) Run

func (cmd *LoginUserCommand) Run(c *client.Client, args []string) error

Run makes the HTTP request corresponding to the LoginUserCommand command.

Jump to