Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type LoginUserCommand ¶
LoginUserCommand is the command line data structure for the login action of user
func (*LoginUserCommand) RegisterFlags ¶
func (cmd *LoginUserCommand) RegisterFlags(cc *cobra.Command, c *client.Client)
RegisterFlags registers the command flags with the command line.
Click to show internal directories.
Click to hide internal directories.